import {
  Body,
  Controller,
  Delete,
  Post,
  Request,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiBody, ApiOperation, ApiTags } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { EquipoTipoEntradaService } from './equipo-tipo-entrada.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { Operador } from '../operador/entity/operador.entity';
import { CreateEquipoTipoEntradaDto } from './dto/input/create.dto';
import { DeleteEquipoTipoEntradaDto } from './dto/input/delete.dto';
import { MessageOutputDto } from '../dto/output/message.dto';

@Controller('equipo-tipo-entrada')
@ApiTags('equipo-tipo-entrada')
export class EquipoTipoEntradaController {
  constructor(
    private equipoTipoEntradaService: EquipoTipoEntradaService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Serealize(MessageOutputDto)
  @Post()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Endpoint que crea una relación entre un equipo y un tipo de entrada.',
  })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Ambas variables son obligatorios.',
    examples: { ejemplo: { value: { id_equipo: 1, id_tipo_entrada: 1 } } },
  })
  create(@Request() req, @Body() body: CreateEquipoTipoEntradaDto) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarAdminOperador(operador);
    return this.equipoTipoEntradaService.asignar(
      body.id_equipo,
      body.id_tipo_entrada,
    );
  }

  @Serealize(MessageOutputDto)
  @Delete()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Endpoint que elimina una relación entre un equipo y un tipo de entrada.',
  })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'La variable id_equipo_tipo_entrada es obligatoria.',
    examples: { ejemplo: { value: { id_equipo_tipo_entrada: 1 } } },
  })
  delete(@Request() req, @Body() body: DeleteEquipoTipoEntradaDto) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarAdminOperador(operador);
    return this.equipoTipoEntradaService.delete(
      operador,
      body.id_equipo_tipo_entrada,
    );
  }
}
