import { Column, Entity, OneToMany, PrimaryGeneratedColumn } from 'typeorm';
import { InstitucionCarrera } from '../../institucion-carrera/entity/institucion-carrera.entity';
import { InstitucionDia } from '../../institucion-dia/entity/institucion-dia.entity';
import { InstitucionInfraccion } from '../../institucion-infraccion/entity/institucion-infraccion.entity';
import { InstitucionPrograma } from '../../institucion-programa/entity/institucion-programa.entity';
import { InstitucionTipoCarrito } from '../../institucion-tipo-carrito/entity/institucion-tipo-carrito.entity';
import { InstitucionTipoEntrada } from '../../institucion-tipo-entrada/entity/institucion-tipo-entrada.entity';
import { Modulo } from '../../modulo/entity/modulo.entity';
import { Operador } from '../../operador/entity/operador.entity';

@Entity()
export class Institucion {
  @PrimaryGeneratedColumn()
  id_institucion: number;

  @Column({ type: Boolean, nullable: false, default: false })
  activo: boolean;

  @Column({ type: String, nullable: false, length: 4 })
  clave: string;

  @Column({ type: String, nullable: true, length: 60 })
  correo: string;

  @Column({ type: Number, nullable: false, default: 7 })
  dias_multa_retraso: number;

  @Column({ type: String, nullable: true, length: 40 })
  dominio: string;

  @Column({ type: String, nullable: false, length: 150 })
  institucion: string;

  @Column({ type: String, nullable: true, length: 60 })
  logo: string;

  @Column({ type: String, nullable: true, length: 60 })
  responsable: string;

  @Column({ type: String, nullable: true, length: 10 })
  telefono: string;

  @Column({ type: Number, nullable: false, default: 15 })
  tiempo_entrega: number;

  @Column({ type: Number, nullable: false, default: 120 })
  tiempo_prestamo: number;

  @Column({ type: Number, nullable: false, default: 10 })
  tiempo_recoger: number;

  @Column({ type: String, nullable: true, length: 100 })
  ubicacion: string;

  @OneToMany(() => InstitucionCarrera, (carrera) => carrera.institucion)
  carreras: InstitucionCarrera[];

  @OneToMany(
    () => InstitucionDia,
    (institucionDia) => institucionDia.institucion,
  )
  dias: InstitucionDia[];

  @OneToMany(
    () => InstitucionInfraccion,
    (institucionInfraccion) => institucionInfraccion.institucion,
  )
  infracciones: InstitucionInfraccion[];

  @OneToMany(
    () => InstitucionPrograma,
    (institucionPrograma) => institucionPrograma.institucion,
  )
  programas: InstitucionPrograma[];

  @OneToMany(
    () => InstitucionTipoCarrito,
    (institucionTipoCarrito) => institucionTipoCarrito.institucion,
  )
  tiposCarrito: InstitucionTipoCarrito[];

  @OneToMany(
    () => InstitucionTipoEntrada,
    (institucionTipoEntrada) => institucionTipoEntrada.institucion,
  )
  tiposEntrada: InstitucionTipoEntrada[];

  @OneToMany(() => Modulo, (modulo) => modulo.institucion)
  modulos: Modulo[];

  @OneToMany(() => Operador, (operador) => operador.institucion)
  operadores: Operador[];
}
