import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Infraccion } from '../../../institucion-infraccion/entity/infraccion.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { InstitucionInfraccion } from '../../../institucion-infraccion/entity/institucion-infraccion.entity';
import { Multa } from '../multa.entity';
import { Operador } from '../../../operador/entity/operador.entity';
import { Prestamo } from '../../../prestamo/entity/prestamo.entity';
import { Usuario } from '../../../usuario/entity/usuario.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('mu.id_multa', 'id_multa')
      .addSelect('mu.activo', 'activo')
      .addSelect('mu.descripcion', 'descripcion')
      .addSelect('mu.fecha_fin', 'fecha_fin')
      .addSelect('mu.fecha_inicio', 'fecha_inicio')
      .addSelect('mu.id_institucion_infraccion', 'id_institucion_infraccion')
      .addSelect('mu.id_operador', 'id_operador')
      .addSelect('mu.id_prestamo', 'id_prestamo')
      .addSelect('mu.retraso', 'retraso')
      .addSelect('ii.id_infraccion', 'id_infraccion')
      .addSelect('om.id_institucion', 'id_institucion')
      .addSelect('om.operador', 'operador')
      .addSelect('p.id_equipo', 'id_equipo')
      .addSelect('p.id_usuario', 'id_usuario')
      .addSelect('inf.infraccion', 'infraccion')
      .addSelect('i.institucion', 'institucion')
      .addSelect('u.usuario', 'usuario')
      .addSelect('u.nombre', 'nombre')
      .from(Multa, 'mu')
      .innerJoin(
        InstitucionInfraccion,
        'ii',
        'ii.id_institucion_infraccion = mu.id_institucion_infraccion',
      )
      .innerJoin(Operador, 'om', 'om.id_operador = mu.id_operador')
      .innerJoin(Prestamo, 'p', 'p.id_prestamo = mu.id_prestamo')
      .innerJoin(Infraccion, 'inf', 'inf.id_infraccion = ii.id_infraccion')
      .innerJoin(Usuario, 'u', 'u.id_usuario = p.id_usuario')
      .innerJoin(Institucion, 'i', 'i.id_institucion = om.id_institucion'),
})
export class FullInformacionMultaView {
  @ViewColumn()
  id_multa: number;

  @ViewColumn()
  activo: number;

  @ViewColumn()
  descripcion: string;

  @ViewColumn()
  fecha_fin: Date;

  @ViewColumn()
  fecha_inicio: Date;

  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_infraccion: number;

  @ViewColumn()
  id_institucion_infraccion: number;

  @ViewColumn()
  id_operador: number;

  @ViewColumn()
  id_prestamo: number;

  @ViewColumn()
  id_usuario: number;

  @ViewColumn()
  infraccion: string;

  @ViewColumn()
  institucion: string;

  @ViewColumn()
  nombre: string;

  @ViewColumn()
  operador: string;

  @ViewColumn()
  retraso: number;

  @ViewColumn()
  usuario: string;
}
